@@ -1,4 +1,5 @@
 use crate::statistic::summary::pnl::PnLReturnSummary;
+use serde::{Deserialize, Serialize};
 
 pub trait Ratio {
     fn init(risk_free_return: f64) -> Self;
@@ -12,7 +13,7 @@ pub trait Ratio {
     }
 }
 
-#[derive(Debug, Clone, PartialOrd, PartialEq)]
+#[derive(Copy, Clone, PartialEq, PartialOrd, Debug, Deserialize, Serialize)]
 pub struct SharpeRatio {
     pub risk_free_return: f64,
     pub trades_per_day: f64,
@@ -53,7 +54,7 @@ impl SharpeRatio {
     }
 }
 
-#[derive(Debug, Clone, PartialOrd, PartialEq)]
+#[derive(Copy, Clone, PartialEq, PartialOrd, Debug, Deserialize, Serialize)]
 pub struct SortinoRatio {
     pub risk_free_return: f64,
     pub trades_per_day: f64,
@@ -94,7 +95,7 @@ impl SortinoRatio {
     }
 }
 
-#[derive(Debug, Clone, PartialOrd, PartialEq)]
+#[derive(Copy, Clone, PartialEq, PartialOrd, Debug, Deserialize, Serialize)]
 pub struct CalmarRatio {
     pub risk_free_return: f64,
     pub trades_per_day: f64,
