@@ -1,22 +1,21 @@
-use crate::data::market::{MarketEvent, MarketMeta};
 use crate::strategy::error::StrategyError;
-use crate::strategy::signal::{Decision, SignalEvent, SignalStrength};
-use crate::strategy::SignalGenerator;
+use crate::strategy::{Decision, SignalEvent, SignalGenerator, SignalStrength};
 use barter_data::model::MarketData;
 use chrono::Utc;
-use serde::Deserialize;
+use serde::{Deserialize, Serialize};
 use std::collections::HashMap;
 use ta::indicators::RelativeStrengthIndex;
 use ta::Next;
+use crate::data::{MarketEvent, MarketMeta};
 
-/// Configuration for constructing a [RSIStrategy] via the new() constructor method.
-#[derive(Debug, Deserialize)]
+/// Configuration for constructing a [`RSIStrategy`] via the new() constructor method.
+#[derive(Copy, Clone, PartialEq, PartialOrd, Debug, Deserialize, Serialize)]
 pub struct Config {
     pub rsi_period: usize,
 }
 
-#[derive(Debug)]
-/// Example RSI based strategy that implements [SignalGenerator].
+#[derive(Clone, Debug)]
+/// Example RSI based strategy that implements [`SignalGenerator`].
 pub struct RSIStrategy {
     rsi: RelativeStrengthIndex,
 }
@@ -41,7 +40,7 @@ impl SignalGenerator for RSIStrategy {
         }
 
         Some(SignalEvent {
-            event_type: SignalEvent::EVENT_TYPE,
+            event_type: SignalEvent::ORGANIC_SIGNAL,
             trace_id: market.trace_id,
             timestamp: Utc::now(),
             exchange: market.exchange,
@@ -56,7 +55,7 @@ impl SignalGenerator for RSIStrategy {
 }
 
 impl RSIStrategy {
-    /// Constructs a new [RSIStrategy] component using the provided configuration struct.
+    /// Constructs a new [`RSIStrategy`] component using the provided configuration struct.
     pub fn new(config: Config) -> Self {
         let rsi_indicator = RelativeStrengthIndex::new(config.rsi_period)
             .expect("Failed to construct RSI indicator");
@@ -64,13 +63,13 @@ impl RSIStrategy {
         Self { rsi: rsi_indicator }
     }
 
-    /// Returns a [RSIStrategyBuilder] instance.
+    /// Returns a [`RSIStrategyBuilder`] instance.
     pub fn builder() -> RSIStrategyBuilder {
         RSIStrategyBuilder::new()
     }
 
-    /// Given the latest RSI value for a symbol, generates a map containing the [SignalStrength] for
-    /// [Decision] under consideration.
+    /// Given the latest RSI value for a symbol, generates a map containing the [`SignalStrength`] for
+    /// [`Decision`] under consideration.
     fn generate_signals_map(rsi: f64) -> HashMap<Decision, SignalStrength> {
         let mut signals = HashMap::with_capacity(4);
         if rsi < 40.0 {
@@ -94,13 +93,13 @@ impl RSIStrategy {
         signals
     }
 
-    /// Calculates the [SignalStrength] of a particular [Decision].
+    /// Calculates the [`SignalStrength`] of a particular [`Decision`].
     fn calculate_signal_strength() -> f32 {
         1.0
     }
 }
 
-/// Builder to construct [RSIStrategy] instances.
+/// Builder to construct [`RSIStrategy`] instances.
 #[derive(Debug, Default)]
 pub struct RSIStrategyBuilder {
     rsi: Option<RelativeStrengthIndex>,
@@ -112,16 +111,11 @@ impl RSIStrategyBuilder {
     }
 
     pub fn rsi(self, value: RelativeStrengthIndex) -> Self {
-        Self {
-            rsi: Some(value),
-            ..self
-        }
+        Self { rsi: Some(value) }
     }
 
     pub fn build(self) -> Result<RSIStrategy, StrategyError> {
-        let rsi = self.rsi.ok_or(StrategyError::BuilderIncomplete)?;
-
-        Ok(RSIStrategy { rsi })
+        Ok(RSIStrategy { rsi: self.rsi.ok_or(StrategyError::BuilderIncomplete)? })
     }
 }
 
@@ -140,4 +134,4 @@ mod tests {
                 && actual_signals.contains_key(&Decision::CloseShort)
         )
     }
-}
+}
\ No newline at end of file
